@@ -29,8 +29,11 @@ example_sim_meta = {
         },
         'C': {  # Doesn't acutally exist. Used for testing.
             'public': False,
-        }
+        },
     },
+    'extra_methods': [
+        'example_method',
+    ],
 }
 
 
@@ -39,8 +42,10 @@ class ExampleSim(mosaik_api.Simulator):
         super(ExampleSim, self).__init__(example_sim_meta)
         self.step_size = None
         self.simulators = []
+        self.value = None  # May be set in example_method()
 
     def init(self, sid, step_size=1):
+        self.sid = sid
         self.step_size = step_size
         return self.meta
 
@@ -75,6 +80,10 @@ class ExampleSim(mosaik_api.Simulator):
                 data[eid][attr] = self.simulators[sid].results[idx]
         return data
 
+    def example_method(self, value):
+        self.value = value
+        return value
+
 
 def main():
     return mosaik_api.start_simulation(ExampleSim())
